@@ -71,6 +71,12 @@ class CreateDBInstanceRequest(RpcRequest):
 	def set_StorageEngine(self,StorageEngine):
 		self.add_query_param('StorageEngine',StorageEngine)
 
+	def get_ResourceGroupId(self):
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self,ResourceGroupId):
+		self.add_query_param('ResourceGroupId',ResourceGroupId)
+
 	def get_SecurityToken(self):
 		return self.get_query_params().get('SecurityToken')
 
